@@ -1,6 +1,6 @@
-library(vines)
+library("vines")
 
-N <- 10 # Number of values of each variable.
+N <- 7 # Number of values of each variable.
 P <- 5 # Number of values of each parameter.
 T <- 0.01 # Tolerance checking for equality.
 
@@ -12,8 +12,8 @@ copulas <- c(
         lapply(seq(from = -1, to = 1, length = P), 
                 function (rho) normalCopula(rho)),
         apply(merge(seq(from = -1, to = 1, length = P),
-                        as.integer(seq(from = 1, to = 30, length = P))), 1,
-                function (p) tCopula(p[1], df = p[2], df.fixed = TRUE)),
+                        seq(from = 1, to = 30, length = P)), 1,
+                function (p) tCopula(p[1], df = as.integer(p[2]), df.fixed = TRUE)),
         lapply(seq(from = .Machine$double.eps^0.5, to = 3, length = P),
                 function (theta) claytonCopula(theta)),
         lapply(seq(from = 1, to = 5, length = P),
@@ -48,7 +48,7 @@ copulas <- c(
                 function (rho) normalCopula(rho)),
         apply(merge(seq(from = -1, to = 1, length = P),
                         seq(from = 1, to = 30, length = P)), 1,
-                function (p) tCopula(p[1], df = p[2], df.fixed = TRUE)),
+                function (p) tCopula(p[1], df = as.integer(p[2]), df.fixed = TRUE)),
         lapply(seq(from = .Machine$double.eps^0.5, to = 100, length = P),
                 function (theta) claytonCopula(theta)),
         lapply(seq(from = 1, to = 100, length = P),
